package pps.core.base.utils;

import org.apache.commons.lang3.StringUtils;
import pps.cloud.system.service.SysOrganizationCloudService;
import pps.cloud.system.service.SystemAreaService;
import pps.cloud.system.service.SystemDictionaryService;
import pps.cloud.system.service.data.*;
import xstartup.base.XContext;
import xstartup.data.XListResult;
import xstartup.data.XSingleResult;

import java.util.List;
import java.util.Optional;

/**
 * 封装工具类
 *
 * @author ZWT
 * @date 2023/08/25 16:08
 */
public class DictUtils {

    /*-------------------------服务调用-------------------------*/

    /**
     * 通过字典类型查询字典
     *
     * @param context 上下文
     * @param alias   别名
     * @return {@link List}<{@link QuerySysDictionaryViewOutput}>
     */
    public static List<QuerySysDictionaryViewOutput> getDictList(XContext context, String alias) {
        QuerySysDictionaryViewInput dictInput = new QuerySysDictionaryViewInput();
        dictInput.setAlias(alias);
        dictInput.setPage(1);
        dictInput.setLimit(999);
        SystemDictionaryService dictionaryService = context.getBean(SystemDictionaryService.class);
        XListResult<QuerySysDictionaryViewOutput> dictPageResult = dictionaryService.queryChildSysDictionarysByParentAlias(context, dictInput);
        dictPageResult.throwIfFail();
        return dictPageResult.getResult();
    }

    /**
     * 通过组织id获取系统组织名称
     *
     * @param context 上下文
     * @param ouId    组织id
     * @return {@link String}
     */
    public static String getSysOrgNameById(XContext context, String ouId) {
        SysOrganizationCloudService orgCloudService = context.getBean(SysOrganizationCloudService.class);
        GetSysOrganizationViewInput viewInput = new GetSysOrganizationViewInput();
        viewInput.setId(ouId);
        XSingleResult<GetSysOrganizationViewOutput> organization = orgCloudService.getSysOrganizationById(context, viewInput);
        organization.throwIfFail();
        return Optional.ofNullable(organization.getResult())
                .map(GetSysOrganizationViewOutput::getOuName)
                .orElse(null);
    }

    /**
     * 获得系统输出列表区域
     *
     * @param context 上下文
     * @return {@link List}<{@link GetSysAreaOutput}>
     */
    public static List<GetSysAreaOutput> getSysAreaOutputList(XContext context) {
        SystemAreaService systemAreaService = context.getBean(SystemAreaService.class);
        XListResult<GetSysAreaOutput> sysAreaList = systemAreaService.getSysAreaList(context, new GetSysAreaInput());
        sysAreaList.throwIfFail();
        return sysAreaList.getResult();
    }

    /*-------------------------其他-------------------------*/

    /**
     * 通过字典编码匹配查询字典名称
     *
     * @param dictList dict类型列表
     * @param dicKey   dic关键
     * @return {@link String}
     */
    public static String getDicNameByStream(List<QuerySysDictionaryViewOutput> dictList, String dicKey) {
        return dictList.stream()
                .filter(row -> StringUtils.equals(row.getDicKey(), dicKey))
                .map(QuerySysDictionaryViewOutput::getDicName)
                .findAny()
                .orElse(null);
    }

    /**
     * 通过地区ID匹配查询地区名称
     *
     * @param areaList 区域列表
     * @param areaCode 区号
     * @return {@link String}
     */
    public static String getAreaNameByStream(List<GetSysAreaOutput> areaList, Integer areaCode) {
        return areaList.stream()
                .filter(area -> area.getId().equals(areaCode))
                .map(GetSysAreaOutput::getName)
                .findAny()
                .orElse("其他地区");
    }
}